###
# Application: pyFind
# File:        __init__.py
# Description: 
# Copyright (c) 2001-2002   Andy Balcombe <kinematics _at_ ntlworld.com>
###
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""pyFind package"""

#i18n stuff 
try:
    import gettext
    import commands
    
    domain = 'pyfind'
    
    data_dir = commands.getoutput('gnome-config --datadir')
    locale_dir = data_dir + '/locale'
    
    gettext.bindtextdomain(domain, locale_dir)
    gettext.textdomain(domain)
    
except IOError:
    print "IOError in __init__.py"
    pass
    
import __builtin__
__builtin__.__dict__['_'] = gettext.gettext
